var texts = {
"select": "Select",
"selectall": "Select all",
"filter": "Filter",
"clear": "Clear filter",
"opacity": "Opacity",
"speed": "Speed",
"period": "Period",
"showonlyselecteditems": "Show only selected items",
"markers": "markers",
"entities": "entities",
"links": "links",
"matchedintable": "Matched in table",
"selectsomeitems": "Select some items in the map to see its attributes",
"noitems": "No",
"inthemap": "in the map",
"show": "Show",
"more": "more",
"less": "less",
"Label": "Label",
"Color": "Color",
"Size": "Size",
"Shape": "Shape",
"selectacolorscalefor": "Select a color scale for",
"selectacolorfor": "Select a color for",
"selectashapefor": "Select a shape for",
"selectcustomcolor": "Select a custom color",
"legends": "Legends",
"tools": "Tools",
"relative": "Relative",
"absolute": "Absolute",
"selectattribute": "Select an attribute to display as ",
"none": "none",
"default": "default",
"searchsomething": "Search something...",
"changespeed": "Change speed"
}
